@@ -102,7 +102,7 @@ public class FacebookServiceImpl implements FacebookService {
         try {
             account = oAuthService.getAccount(accountId, session, user, contextId);
         } catch (final OXException e) {
-            LOG.error(e);
+            LOG.error(e.getMessage(), e);
         }
         if (null != account) {
             // get the users own profile (for his id) with the given access token
@@ -116,7 +116,7 @@ public class FacebookServiceImpl implements FacebookService {
                 final JSONObject object = new JSONObject(ownProfileResponse.getBody());
                 myuid = object.getString("id");
             } catch (final JSONException e) {
-                LOG.error(e);
+                LOG.error(e.getMessage(), e);
             }
 
             // get the users connections
@@ -169,7 +169,7 @@ public class FacebookServiceImpl implements FacebookService {
                     try {
                         OXContainerConverter.loadImageFromURL(contact, (String) connection.get("pic_big"));
                     } catch (final ConverterException e) {
-                        LOG.error(e);
+                        LOG.error(e.getMessage(), e);
                     }
                 }
 
@@ -217,7 +217,7 @@ public class FacebookServiceImpl implements FacebookService {
         	} catch (final JSONException x) {
         		// Give up
         	}
-            LOG.error(e);
+            LOG.error(e.getMessage(), e);
         }
 
         return contacts;
@@ -230,7 +230,7 @@ public class FacebookServiceImpl implements FacebookService {
             final OAuthAccount account = oAuthService.getAccount(accountId, session, user, contextId);
             displayName = account.getDisplayName();
         } catch (final OXException e) {
-            LOG.error(e);
+            LOG.error(e.getMessage(), e);
         }
         return displayName;
     }
